# ===================================================================================
# Upgrade-CopyMove.ps1
# (c) SharePoint Products 2010-2016
#
# CopyMove 2016 upgrade script
# ===================================================================================

$myWindowsID=[System.Security.Principal.WindowsIdentity]::GetCurrent()
$myWindowsPrincipal=new-object System.Security.Principal.WindowsPrincipal($myWindowsID)
$adminRole=[System.Security.Principal.WindowsBuiltInRole]::Administrator
if ($myWindowsPrincipal.IsInRole($adminRole))
{
	$Host.UI.RawUI.BackgroundColor = "DarkBlue"
	clear-host
} else
{
    $arguments = $myInvocation.MyCommand.Definition;
    Start-Process powershell.exe -Verb RunAs -ArgumentList "-file `"$arguments`"";
    exit;
}

$Host.UI.RawUI.WindowTitle = "Upgrading CopyMove 2016"
$0 = $myInvocation.MyCommand.Definition
$dp0 = [System.IO.Path]::GetDirectoryName($0)
. "$dp0\Functions.ps1"

Load-SharePoint-Powershell;

Write-Host "Checking current version ..." -NoNewline;
$upgradeMinimumVersion = New-Object System.Version("4.0.0.0");
$installedVersion = Get-InstalledVersion;

if ($installedVersion -eq $null)
{
	Write-Host " CopyMove 2016 is not installed!";
} elseif ($installedVersion -lt $upgradeMinimumVersion)
{
	Write-Host " $installedVersion";
    Write-Warning "The currently installed version cannot be upgraded! Please reinstall CopyMove by first uninstalling the old version using the Uninstall-CopyMove.cmd script. Then install the new version using the Install-CopyMove.cmd script. The reinstall is safe and will not drop any settings.";
} else
{
	Write-Host " $installedVersion";
    Write-Host "Upgrading CopyMove 2016 ...";

	Write-Host "Disabling CopyMove farm feature ..." -NoNewline;
	$farmFeature = Get-SPFeature -Identity SPPCopyMoveFarm -Farm -ea SilentlyContinue;
	if ($farmFeature -ne $null)
	{
	    Disable-SPFeature -Identity SPPCopyMoveFarm -Confirm:$false
	    Write-Host -f Green " success";
	} else
	{
	    Write-Host -f Yellow " skipped - feature not active";
	}

    Upgrade-FarmSolution "sharepointproducts_platform2016.wsp" "$dp0\..\WSP\sharepointproducts_platform2016.wsp";
    Upgrade-FarmSolution "sharepointproducts_copymove2016.wsp" "$dp0\..\WSP\sharepointproducts_copymove2016.wsp";

    $ServiceNames=@("SPTimerV4")
    Restart-SharePointServicesOnAllServers $ServiceNames;

	Write-Host "Enabling CopyMove farm feature ..." -NoNewline;
	Enable-SPFeature -Identity SPPCopyMoveFarm -Force
    Write-Host -f Green " success";

	Write-Host ""
	Write-Host "Upgrade complete - configure CopyMove as follows:"
	Write-Host "1. Navigate to 'Central Administation -> Manage farm features'"
	Write-Host "2. Ensure that the feature 'SharePoint Products - CopyMove for SharePoint 2016' is activated"
	Write-Host "3. Activate the CopyMove site collection feature feature on all applicable site collections"
	Write-Host "4. Optionally change default settings from 'Central Administration -> CopyMove settings'"
	Write-Host "5. Done"
	Write-Host ""
}

Pause

